@@ -86,7 +86,7 @@
 #define KDNSSD_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDNSSD_NO_DEPRECATED
-#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KDNSSD_NO_DEPRECATED_WARNINGS
 #  define KDNSSD_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDNSSD_DEPRECATED_WARNINGS_SINCE KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KDNSSD_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDNSSD_NO_DEPRECATED
-#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KDNSSD_NO_DEPRECATED_WARNINGS
 #  define KDNSSD_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDNSSD_DEPRECATED_WARNINGS_SINCE KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
